lilypondfiletools.ScoreBlock
============================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.lilypond_format

    Inherited from :py:class:`lilypondfiletools.NonattributedBlock <abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.NonattributedBlock>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.is_formatted_when_empty

    Inherited from :py:class:`lilypondfiletools.NonattributedBlock <abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.NonattributedBlock>`

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.append

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.count

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.extend

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.index

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.insert

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.pop

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.remove

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.reverse

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.sort

    Inherited from :py:class:`__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__add__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__contains__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__delitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__delslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__eq__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__ge__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__getitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__getslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__gt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__iadd__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__imul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__iter__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__le__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__len__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__lt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__mul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__ne__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__repr__

    Inherited from :py:class:`lilypondfiletools.NonattributedBlock <abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.NonattributedBlock>`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__reversed__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__rmul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__setitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__setslice__

    Inherited from :py:class:`__builtin__.list`
